@@ -686,11 +686,11 @@ pub fn process_file_with_formatter(
             });
         }
 
-        // Don't actually write the file in diff mode
+        // Don't actually write the file in diff mode, but report how many would be fixed
         return (
-            total_warnings > 0,
+            total_warnings > 0 || warnings_fixed > 0,
             total_warnings,
-            0,
+            warnings_fixed,
             fixable_warnings,
             all_warnings,
             file_index,
@@ -1125,7 +1125,7 @@ pub fn apply_fixes_coordinated(
                     let rule_codes: Vec<&str> = result.fixed_rule_names.iter().map(|s| s.as_str()).collect();
                     eprintln!("Rule codes: {}", rule_codes.join(", "));
                 }
-                eprintln!("Please report at: https://github.com/rvben/rumdl/issues/new");
+                eprintln!("Please report at: https://github.com/rvben/rumdl/issues/new?template=bug_report.yml");
             }
 
             // Count warnings for the rules that were successfully applied
