@@ -95,9 +95,13 @@ impl ContentCharacteristics {
             {
                 chars.has_lists = true;
             }
+            // Ordered lists: line starts with digit, or blockquote line contains digit followed by period
             if !chars.has_lists
-                && line.chars().next().is_some_and(|c| c.is_ascii_digit())
-                && (line.contains(". ") || line.contains('.'))
+                && ((line.chars().next().is_some_and(|c| c.is_ascii_digit())
+                    && (line.contains(". ") || line.contains('.')))
+                    || (trimmed.starts_with('>')
+                        && trimmed.chars().any(|c| c.is_ascii_digit())
+                        && (trimmed.contains(". ") || trimmed.contains('.'))))
             {
                 chars.has_lists = true;
             }
@@ -282,6 +286,11 @@ pub fn lint_and_index(
         #[cfg(not(target_arch = "wasm32"))]
         let _rule_start = Instant::now();
 
+        // Skip rules that indicate they should be skipped (opt-in rules, content-based skipping)
+        if rule.should_skip(&lint_ctx) {
+            continue;
+        }
+
         // Run single-file check
         let result = rule.check(&lint_ctx);
 
