@@ -3,6 +3,8 @@
 /// See [docs/md013.md](../../docs/md013.md) for full documentation, configuration, and examples.
 use crate::rule::{LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::rule_config_serde::RuleConfig;
+use crate::utils::mkdocs_attr_list::is_standalone_attr_list;
+use crate::utils::mkdocs_snippets::is_snippet_block_delimiter;
 use crate::utils::range_utils::LineIndex;
 use crate::utils::range_utils::calculate_excess_range;
 use crate::utils::regex_cache::{
@@ -43,7 +45,7 @@ impl MD013LineLength {
                 reflow: false,
                 reflow_mode: ReflowMode::default(),
                 length_mode: LengthMode::default(),
-                abbreviations: None,
+                abbreviations: Vec::new(),
             },
         }
     }
@@ -511,6 +513,7 @@ impl MD013LineLength {
                     CodeBlock(String, usize),      // content and original indent
                     NestedListItem(String, usize), // full line content and original indent
                     SemanticLine(String),          // Lines starting with NOTE:, WARNING:, etc that should stay separate
+                    SnippetLine(String),           // MkDocs Snippets delimiters (-8<-) that must stay on their own line
                     Empty,
                 }
 
@@ -614,6 +617,11 @@ impl MD013LineLength {
                             // Check if this is a semantic line (NOTE:, WARNING:, etc.)
                             else if is_semantic_line(&content) {
                                 list_item_lines.push(LineType::SemanticLine(content));
+                            }
+                            // Check if this is a snippet block delimiter (-8<- or --8<--)
+                            // These must be preserved on their own lines for MkDocs Snippets extension
+                            else if is_snippet_block_delimiter(&content) {
+                                list_item_lines.push(LineType::SnippetLine(content));
                             } else {
                                 list_item_lines.push(LineType::Content(content));
                             }
@@ -646,6 +654,7 @@ impl MD013LineLength {
                     },
                     NestedList(Vec<(String, usize)>), // (content, indent) pairs for nested list items
                     SemanticLine(String), // Semantic markers like NOTE:, WARNING: that stay on their own line
+                    SnippetLine(String),  // MkDocs Snippets delimiter that stays on its own line without extra spacing
                     Html {
                         lines: Vec<String>,        // HTML content preserved exactly as-is
                         has_preceding_blank: bool, // Whether there was a blank line before this block
@@ -945,6 +954,36 @@ impl MD013LineLength {
                             blocks.push(Block::SemanticLine(content.clone()));
                             had_preceding_blank = false; // Reset after semantic line
                         }
+                        LineType::SnippetLine(content) => {
+                            // Snippet delimiters (-8<-) are standalone - flush any current block and add as separate block
+                            // Unlike semantic lines, snippet lines don't add extra blank lines around them
+                            if in_code {
+                                blocks.push(Block::Code {
+                                    lines: current_code_block.clone(),
+                                    has_preceding_blank: code_block_has_preceding_blank,
+                                });
+                                current_code_block.clear();
+                                in_code = false;
+                            } else if in_nested_list {
+                                blocks.push(Block::NestedList(current_nested_list.clone()));
+                                current_nested_list.clear();
+                                in_nested_list = false;
+                            } else if in_html_block {
+                                blocks.push(Block::Html {
+                                    lines: current_html_block.clone(),
+                                    has_preceding_blank: html_block_has_preceding_blank,
+                                });
+                                current_html_block.clear();
+                                html_tag_stack.clear();
+                                in_html_block = false;
+                            } else if !current_paragraph.is_empty() {
+                                blocks.push(Block::Paragraph(current_paragraph.clone()));
+                                current_paragraph.clear();
+                            }
+                            // Add snippet line as its own block
+                            blocks.push(Block::SnippetLine(content.clone()));
+                            had_preceding_blank = false;
+                        }
                     }
                 }
 
@@ -991,10 +1030,13 @@ impl MD013LineLength {
                     let has_nested_lists = blocks.iter().any(|b| matches!(b, Block::NestedList(_)));
                     let has_code_blocks = blocks.iter().any(|b| matches!(b, Block::Code { .. }));
                     let has_semantic_lines = blocks.iter().any(|b| matches!(b, Block::SemanticLine(_)));
+                    let has_snippet_lines = blocks.iter().any(|b| matches!(b, Block::SnippetLine(_)));
                     let has_paragraphs = blocks.iter().any(|b| matches!(b, Block::Paragraph(_)));
 
-                    // If we have nested lists, code blocks, or semantic lines but no paragraphs, don't normalize
-                    if (has_nested_lists || has_code_blocks || has_semantic_lines) && !has_paragraphs {
+                    // If we have nested lists, code blocks, semantic lines, or snippet lines but no paragraphs, don't normalize
+                    if (has_nested_lists || has_code_blocks || has_semantic_lines || has_snippet_lines)
+                        && !has_paragraphs
+                    {
                         return false;
                     }
 
@@ -1062,7 +1104,7 @@ impl MD013LineLength {
                         break_on_sentences: true,
                         preserve_breaks: false,
                         sentence_per_line: config.reflow_mode == ReflowMode::SentencePerLine,
-                        abbreviations: config.abbreviations.clone(),
+                        abbreviations: config.abbreviations_for_reflow(),
                     };
 
                     let mut result: Vec<String> = Vec::new();
@@ -1134,13 +1176,15 @@ impl MD013LineLength {
 
                                 // Add blank line after paragraph block if there's a next block
                                 // BUT: check if next block is a code block that doesn't want a preceding blank
+                                // Also don't add blank lines before snippet lines (they should stay tight)
                                 if block_idx < blocks.len() - 1 {
                                     let next_block = &blocks[block_idx + 1];
                                     let should_add_blank = match next_block {
                                         Block::Code {
                                             has_preceding_blank, ..
                                         } => *has_preceding_blank,
-                                        _ => true, // For all other blocks, add blank line
+                                        Block::SnippetLine(_) => false, // No blank line before snippet delimiters
+                                        _ => true,                      // For all other blocks, add blank line
                                     };
                                     if should_add_blank {
                                         result.push(String::new());
@@ -1199,7 +1243,8 @@ impl MD013LineLength {
                                         Block::Code {
                                             has_preceding_blank, ..
                                         } => *has_preceding_blank,
-                                        _ => true, // For all other blocks, add blank line
+                                        Block::SnippetLine(_) => false, // No blank line before snippet delimiters
+                                        _ => true,                      // For all other blocks, add blank line
                                     };
                                     if should_add_blank {
                                         result.push(String::new());
@@ -1230,13 +1275,27 @@ impl MD013LineLength {
                                         Block::Code {
                                             has_preceding_blank, ..
                                         } => *has_preceding_blank,
-                                        _ => true, // For all other blocks, add blank line
+                                        Block::SnippetLine(_) => false, // No blank line before snippet delimiters
+                                        _ => true,                      // For all other blocks, add blank line
                                     };
                                     if should_add_blank {
                                         result.push(String::new());
                                     }
                                 }
                             }
+                            Block::SnippetLine(content) => {
+                                // Preserve snippet delimiters (-8<-) as-is on their own line
+                                // Unlike semantic lines, snippet lines don't add extra blank lines
+                                if is_first_block {
+                                    // First block starts with marker
+                                    result.push(format!("{marker}{content}"));
+                                    is_first_block = false;
+                                } else {
+                                    // Subsequent blocks use expected indent
+                                    result.push(format!("{expected_indent}{content}"));
+                                }
+                                // No blank lines added before or after snippet delimiters
+                            }
                             Block::Html {
                                 lines: html_lines,
                                 has_preceding_blank: _,
@@ -1268,7 +1327,8 @@ impl MD013LineLength {
                                         Block::Html {
                                             has_preceding_blank, ..
                                         } => *has_preceding_blank,
-                                        _ => true, // For all other blocks, add blank line
+                                        Block::SnippetLine(_) => false, // No blank line before snippet delimiters
+                                        _ => true,                      // For all other blocks, add blank line
                                     };
                                     if should_add_blank {
                                         result.push(String::new());
@@ -1375,6 +1435,8 @@ impl MD013LineLength {
                     || is_horizontal_rule(next_trimmed)
                     || (next_trimmed.starts_with('[') && next_line.contains("]:"))
                     || is_template_directive_only(next_line)
+                    || is_standalone_attr_list(next_line)
+                    || is_snippet_block_delimiter(next_line)
                 {
                     break;
                 }
@@ -1405,6 +1467,16 @@ impl MD013LineLength {
                 continue;
             }
 
+            // Skip reflowing if this paragraph contains MkDocs Snippets markers
+            // Snippets blocks (-8<- ... -8<-) should be preserved exactly
+            let contains_snippets = paragraph_lines.iter().any(|line| is_snippet_block_delimiter(line));
+
+            if contains_snippets {
+                // Don't reflow Snippets blocks - skip this paragraph
+                i = paragraph_start + paragraph_lines.len();
+                continue;
+            }
+
             // Check if this paragraph needs reflowing
             let needs_reflow = match config.reflow_mode {
                 ReflowMode::Normalize => {
@@ -1483,7 +1555,7 @@ impl MD013LineLength {
                     break_on_sentences: true,
                     preserve_breaks: false,
                     sentence_per_line: config.reflow_mode == ReflowMode::SentencePerLine,
-                    abbreviations: config.abbreviations.clone(),
+                    abbreviations: config.abbreviations_for_reflow(),
                 };
                 let mut reflowed = crate::utils::text_reflow::reflow_line(&paragraph_text, &reflow_options);
 
