@@ -161,8 +161,9 @@ fn test_invalid_markdownlint_json_prints_helpful_error() {
         stderr.contains("Failed to parse JSON"),
         "Expected helpful parse error message, got: {stderr}"
     );
+    // Check for the filename (not full path, since #291 changed to relative paths)
     assert!(
-        stderr.contains(config_path.to_str().unwrap()),
+        stderr.contains(".markdownlint.json"),
         "Error message should include the config filename, got: {stderr}"
     );
 }
