@@ -4,9 +4,9 @@ use rumdl_lib::rules::MD001HeadingIncrement;
 
 #[test]
 pub fn test_md001_unicode_valid() {
-    let rule = MD001HeadingIncrement;
+    let rule = MD001HeadingIncrement::default();
     let content = "# Heading with café\n## Heading with 汉字\n### Heading with emoji 🔥\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -16,9 +16,9 @@ pub fn test_md001_unicode_valid() {
 
 #[test]
 pub fn test_md001_unicode_invalid() {
-    let rule = MD001HeadingIncrement;
+    let rule = MD001HeadingIncrement::default();
     let content = "# Heading with café\n### Heading with 汉字\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(
         result.len(),
@@ -31,9 +31,9 @@ pub fn test_md001_unicode_invalid() {
 
 #[test]
 pub fn test_md001_unicode_fix() {
-    let rule = MD001HeadingIncrement;
+    let rule = MD001HeadingIncrement::default();
     let content = "# Café heading\n### 汉字 heading\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.fix(&ctx).unwrap();
     assert_eq!(
         result, "# Café heading\n## 汉字 heading\n",
@@ -43,9 +43,9 @@ pub fn test_md001_unicode_fix() {
 
 #[test]
 pub fn test_md001_unicode_multiple_violations() {
-    let rule = MD001HeadingIncrement;
+    let rule = MD001HeadingIncrement::default();
     let content = "# café\n### 汉字\n##### 🔥\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2, "Multiple violations with Unicode should be detected");
     assert_eq!(result[0].line, 2);
@@ -54,9 +54,9 @@ pub fn test_md001_unicode_multiple_violations() {
 
 #[test]
 pub fn test_md001_unicode_atx_and_setext() {
-    let rule = MD001HeadingIncrement;
+    let rule = MD001HeadingIncrement::default();
     let content = "# Heading café\nHeading 汉字\n---------\n### Heading 🔥\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -66,9 +66,9 @@ pub fn test_md001_unicode_atx_and_setext() {
 
 #[test]
 pub fn test_md001_unicode_complex() {
-    let rule = MD001HeadingIncrement;
+    let rule = MD001HeadingIncrement::default();
     let content = "# 汉字 café 🔥\n## مرحبا こんにちは\n### Mixed Unicode: ñáéíóú привет שלום\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -76,7 +76,7 @@ pub fn test_md001_unicode_complex() {
     );
 
     let invalid_content = "# 汉字 café 🔥\n### مرحبا こんにちは\n";
-    let ctx = LintContext::new(invalid_content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(invalid_content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(
         result.len(),
@@ -84,7 +84,7 @@ pub fn test_md001_unicode_complex() {
         "Skipped heading level with complex Unicode should trigger warning"
     );
 
-    let ctx = LintContext::new(invalid_content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(invalid_content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(
         fixed, "# 汉字 café 🔥\n## مرحبا こんにちは\n",
