@@ -33,14 +33,14 @@ Die Überprüfung der Backupintegrität ist wichtig für die Zuverlässigkeit.
 Teste äöü ÄÖÜ ß in verschiedenen Kontexten."#;
 
     // This should not panic when checking if list items are in code blocks
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
 
     // Run various rules that might interact with list detection and code blocks
     let rules: Vec<Box<dyn Rule>> = vec![
         Box::new(MD004UnorderedListStyle::default()),
         Box::new(MD005ListIndent::default()),
         Box::new(MD007ULIndent::default()),
-        Box::new(MD032BlanksAroundLists),
+        Box::new(MD032BlanksAroundLists::default()),
     ];
 
     for rule in &rules {
@@ -72,7 +72,7 @@ fn test_umlauts_in_code_spans_within_lists() {
 - Item with multiple `äöü` and `ÄÖÜ` code spans
 - Regular text: Die Größe der Änderungen überprüfen"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
 
     // Test MD038 which checks for spaces in code spans
     let rule = MD038NoSpaceInCode::default();
@@ -99,12 +99,12 @@ Text with ü right after code block.
     ```
 - Item with ß after code"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
 
     // Test rules that analyze code blocks and lists
     let rules: Vec<Box<dyn Rule>> = vec![
         Box::new(MD031BlanksAroundFences::default()),
-        Box::new(MD032BlanksAroundLists),
+        Box::new(MD032BlanksAroundLists::default()),
         Box::new(MD046CodeBlockStyle::from_config_struct(Default::default())),
     ];
 
@@ -135,7 +135,7 @@ fn test_multibyte_characters_at_slice_boundaries() {
 
     for (content, description) in test_cases {
         let list_content = format!("- {content}\n- Another item");
-        let ctx = LintContext::new(&list_content, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(&list_content, rumdl_lib::config::MarkdownFlavor::Standard, None);
 
         // Test list-related rules
         let rules: Vec<Box<dyn Rule>> = vec![
@@ -168,11 +168,11 @@ fn test_code_block_detection_with_utf8_boundaries() {
     ```
 - Item with ö"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
 
     // Test that we can check rules without panicking
     // This triggers the internal list parsing and code block detection
-    let rule = MD032BlanksAroundLists;
+    let rule = MD032BlanksAroundLists::default();
     let result = std::panic::catch_unwind(std::panic::AssertUnwindSafe(|| rule.check(&ctx)));
 
     // This should not panic
@@ -198,7 +198,7 @@ fn test_escaped_backticks_with_umlauts() {
 - Item with `regular code` and ö
 - Item with \`escaped\` and ü mixed"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
 
     // Test MD038 which was reporting false positives
     let rule = MD038NoSpaceInCode::default();
